@@ -25,3 +25,8 @@ void GetOpinionSink::setPlugin(Plugin *plugin) {
 QImage GetOpinionSink::getImage() {
     return image;
 }
+
+
+void GetOpinionSink::emitIsReady() {
+    emit isReady();
+}
