@@ -26,3 +26,7 @@ void GiveOpinionSink::setPlugin(Plugin *plugin) {
 QImage GiveOpinionSink::getImage() {
     return image;
 }
+
+void GiveOpinionSink::emitIsReady() {
+    emit isReady();
+}
