@@ -37,6 +37,8 @@ QSet<PluginAction*> Plugin::getPluginActions() {
 void Plugin::barcodeAnalysed(QString barcodeType, QString barcodeData) {
     this->barcodeData = barcodeData;
     this->barcodeType = barcodeType;
+    getOpinionSink->emitIsReady();
+    giveOpinionSink->emitIsReady();
 }
 QString Plugin::getTimestamp() {
     uint time = QDateTime::currentDateTime().toTime_t();
